## Fixing the seed for reproductibility of results
set_random_seed(17);

load("input_test_heuristic_2.sage");

## Continuous gaussian distribution of parameter 1
T = RealDistribution('gaussian', 1)

## compute the median value of the ration
## l_2_norm / l_inf_norm for a Gaussian vector
## of parameter 1, in dimension dim
def med_for_gaussian(dim, nb_tests):
    tmp = [];
    for test in range(nb_tests):
        l2 = 0
        linf = 0
        for i in range(dim):
            x = T.get_random_element()
            l2 += x^2
            if abs(x) > linf:
                linf = abs(x)
        l2 = sqrt(l2)
        tmp += [RR(l2/linf)]
    return median(tmp)

## Graphic to plot
g = Graphics();

## compute the ratio (in log scale) l_2_norm / l_inf_norm
## for gaussian vectors of varying dimension
## compute it for 10 vectors per dimension (to show the variance)
## (add it to g with green points)
med_gaussian = [[dim, med_for_gaussian(dim,1)] for i in range(10) for dim in range(8,50,1)]
med_gaussian += [[dim, med_for_gaussian(dim,1)] for i in range(10) for dim in range(50,200,5)]
for x in med_gaussian:
    g += point([log(x[0]), log(x[1])], color = 'green', alpha = 0.4, marker = '+')

## compute the median ratio (in log scale) l_2_norm / l_inf_norm
## for gaussian vectors of varying dimension
## (add it to g with red points)
med_gaussian = [[dim, med_for_gaussian(dim,200)] for dim in range(8,50,1)]
med_gaussian += [[dim, med_for_gaussian(dim,200)] for dim in range(50,200,5)]
for x in med_gaussian:
    g += point([log(x[0]), log(x[1])], color = 'red', marker = 'x')

## compute the ratio (in log scale) l_2_norm / l_inf_norm
## for the vectors output by Laarhoven's algorithm
## (add it to g with blue points)
for x in res:
   g += point([log(x[0]), log(x[1]/x[2])])


g += point([2.3,1.3], color = 'red', marker = 'x');
g += point([2.3,1.45], color = 'green', marker = '+');
g += point([2.3,1.6]);
g += text("median of Gaussian \n vectors with same nu", [2.7,1.3], color = 'black');
g += text("x Gaussian vector", [2.65,1.45], color = 'black');
g += text("x = v-t for v output by \n Laarhoven's algo on input t", [2.79,1.6], color = 'black');
g += text("log(nu)", [5.2,0.24], color = 'black');
g += text("log( ||x||_2 / ||x||_infty)", [2.4,1.8], color = 'black');

g+= line([(2.2,1.2),(2.2,1.7),(3.3,1.7),(3.3,1.2),(2.2,1.2)], color = 'grey')

## plot the points (green, red and blue) and save the figure
g_pdf = g.plot();
g_pdf.save('output_heuristic_2.pdf');


